package com.olemix.trac.rpc.cli;

import java.net.*; 
import java.text.DateFormat;
import java.util.*;

import org.apache.xmlrpc.client.*;

public class TracRpcApache {

    /**
     * @param args
     */
    public static void main(String[] args) {
    	URL rpc_url; 
    	Integer ticket_id;
    	
    	try {
        	rpc_url = new URL(System.getenv("TRAC_RPC_URL"));
    		ticket_id = Integer.parseInt(System.getenv("TRAC_TICKET_ID"));
    	}
    	catch (NumberFormatException e)
    	{
    		System.err.println("Invalid ticket number");
    		return;
    	}
    	catch (MalformedURLException e) {
    		System.err.println("Invalid RPC URL");
    		return;
		}
    	
    	try {
            XmlRpcClient client = new XmlRpcClient(); 

            XmlRpcClientConfigImpl config = new XmlRpcClientConfigImpl();
            config.setServerURL(rpc_url);
            config.setUserAgent("TracRpcApache.java 0.1");
            client.setConfig(config);
            
            Vector params = new Vector();
            params.addElement(ticket_id);
            params.addElement(new Integer(0));
    
            Object result = client.execute("ticket.changeLog", params);
            Object[] changelog = (Object[]) result;

            DateFormat df = DateFormat.getDateTimeInstance();
            
            for (Object item: changelog) {
            	Object[] change = (Object[]) item; 
                System.out.println("+ Change");
            	if (change.length != 6) {
            		System.out.println("|    Error: Expected 6 elements got " + change.length);
            		continue;
            	}
            	Date time = (Date) change[0];
            	String author = (String) change[1];
            	String field = (String) change[2];
            	Object oldvalue = (String) change[3];
            	Object newvalue = (String) change[4];
            	boolean permanent = ((Integer) change[5]) == 1;
            	
                System.out.print("|    ");
                System.out.println(df.format(time));
                
                System.out.print("|    by ");
                System.out.println(author);
                
                System.out.print("|    ");
                System.out.println((permanent)? "permanent": "transient");
                
                System.out.print("|    field: ");
                System.out.println(field);
                
                System.out.print("|    from: ");
                System.out.println(oldvalue.toString());
                
                System.out.print("|    to: ");
                System.out.println(newvalue.toString());
            }

        } catch (Exception exception) {
            System.err.println("JavaClient: " + exception);
        }
    }

}
